Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Reloader ¶
type Reloader[T any] struct { // contains filtered or unexported fields }
func (*Reloader[T]) Reset ¶
func (h *Reloader[T]) Reset()
Reset worker this is blocking by design if you want to ask worker to reset use ResetTimeout.
func (*Reloader[T]) ResetTimeout ¶
ResetTimeout receives a time.Duration d and waits for given time trying to reset the worker. default value is a Millisecond
Click to show internal directories.
Click to hide internal directories.